[Zope3-checkins]
SVN: Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/
Updated package references.
Stephan Richter
srichter at cosmos.phy.tufts.edu
Thu Sep 8 09:54:04 EDT 2005
Log message for revision 38398:
Updated package references.
Changed:
U Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/ftp/__init__.py
U Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/ftp/sftpserver.py
U Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/ftp/tests/test_ftpserver.py
U Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/ftp/utils.py
U Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/http.py
U Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/main.py
U Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/server.py
U Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/tests/demofs.py
U Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/tests/fstests.py
U Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/tests/test_accesslog.py
U Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/tests/test_docs.py
U Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/tests/test_ftp.py
U Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/tests/test_mkzopeinstance.py
U Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/tests/test_publisher.py
-=-
Modified: Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/ftp/__init__.py
===================================================================
--- Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/ftp/__init__.py 2005-09-08 13:50:32 UTC (rev 38397)
+++ Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/ftp/__init__.py 2005-09-08 13:54:03 UTC (rev 38398)
@@ -14,9 +14,9 @@
"""FTP and SFTP server factories.
"""
-from zope.app.server.server import ServerType
-from zope.app.server.ftp.server import FTPFactory
-from zope.app.server.server import SSHServerType
+from zope.app.twisted.server import ServerType
+from zope.app.twisted.ftp.server import FTPFactory
+from zope.app.twisted.server import SSHServerType
from utils import FTPRequestFactory
from sftpserver import SFTPFactory
Modified: Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/ftp/sftpserver.py
===================================================================
--- Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/ftp/sftpserver.py 2005-09-08 13:50:32 UTC (rev 38397)
+++ Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/ftp/sftpserver.py 2005-09-08 13:54:03 UTC (rev 38398)
@@ -15,7 +15,7 @@
"""
from zope.interface import implements
-from zope.app.server.interfaces import IFileSystem
+from zope.app.twisted.interfaces import IFileSystem
from twisted.cred.portal import IRealm, Portal
from twisted.cred.credentials import IUsernamePassword
Modified: Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/ftp/tests/test_ftpserver.py
===================================================================
--- Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/ftp/tests/test_ftpserver.py 2005-09-08 13:50:32 UTC (rev 38397)
+++ Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/ftp/tests/test_ftpserver.py 2005-09-08 13:54:03 UTC (rev 38398)
@@ -24,10 +24,10 @@
from zope.testing import doctest
-from zope.app.server.ftp.server import FTPFactory
+from zope.app.twisted.ftp.server import FTPFactory
-from zope.app.server.tests.test_publisher import RequestFactory
-from zope.app.server.tests import demofs
+from zope.app.twisted.tests.test_publisher import RequestFactory
+from zope.app.twisted.tests import demofs
class TestServerSetup(TestCase):
@@ -88,9 +88,9 @@
def test_suite():
return TestSuite((
makeSuite(TestServerSetup),
- doctest.DocTestSuite('zope.app.server.ftp.server'),
- doctest.DocTestSuite('zope.app.server.ftp.utils'),
- doctest.DocTestSuite('zope.app.server.ftp.sftpserver'),
+ doctest.DocTestSuite('zope.app.twisted.ftp.server'),
+ doctest.DocTestSuite('zope.app.twisted.ftp.utils'),
+ doctest.DocTestSuite('zope.app.twisted.ftp.sftpserver'),
))
if __name__=='__main__':
Modified: Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/ftp/utils.py
===================================================================
--- Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/ftp/utils.py 2005-09-08 13:50:32 UTC (rev 38397)
+++ Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/ftp/utils.py 2005-09-08 13:54:03 UTC (rev 38398)
@@ -27,7 +27,7 @@
from zope.app.publication.interfaces import IPublicationRequestFactory
from zope.app.publication.ftp import FTPPublication
-from zope.app.server.interfaces import IFileSystem
+from zope.app.twisted.interfaces import IFileSystem
from twisted.cred import checkers, credentials
from twisted.internet import defer
Modified: Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/http.py
===================================================================
--- Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/http.py 2005-09-08 13:50:32 UTC (rev 38397)
+++ Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/http.py 2005-09-08 13:54:03 UTC (rev 38398)
@@ -23,7 +23,7 @@
except ImportError:
from twisted.web2.channel.http import HTTPFactory
-from zope.app.server.server import ServerType, SSLServerType
+from zope.app.twisted.server import ServerType, SSLServerType
from zope.app import wsgi
Modified: Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/main.py
===================================================================
--- Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/main.py 2005-09-08 13:50:32 UTC (rev 38397)
+++ Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/main.py 2005-09-08 13:54:03 UTC (rev 38398)
@@ -32,7 +32,7 @@
import zope.app.appsetup
import zope.app.appsetup.interfaces
from zope.app import wsgi
-from zope.app.server import log
+from zope.app.twisted import log
CONFIG_FILENAME = "zope.conf"
Modified: Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/server.py
===================================================================
--- Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/server.py 2005-09-08 13:50:32 UTC (rev 38397)
+++ Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/server.py 2005-09-08 13:54:03 UTC (rev 38398)
@@ -24,7 +24,7 @@
from zope.interface import implements
from zope.app import zapi
-from zope.app.server.interfaces import IServerType, ISSLServerType, \
+from zope.app.twisted.interfaces import IServerType, ISSLServerType, \
ISSHServerType
class SSLNotSupported(Exception):
@@ -37,12 +37,12 @@
service.kwargs['interface'] or 'localhost',
service.args[0]
))
-
+
class ZopeTCPServer(internet.TCPServer):
def __init__(self, name, *args, **kwargs):
- internet.TCPServer.__init__(self, *args, **kwargs)
+ internet.TCPServer.__init__(self, *args, **kwargs)
self.name = name
def startService(self):
@@ -52,14 +52,14 @@
class ZopeSSLServer(internet.SSLServer):
def __init__(self, name, *args, **kwargs):
- internet.SSLServer.__init__(self, *args, **kwargs)
+ internet.SSLServer.__init__(self, *args, **kwargs)
self.name = name
def startService(self):
internet.SSLServer.startService(self)
logStartUp(self)
-
+
class ServerType(object):
implements(IServerType)
Modified: Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/tests/demofs.py
===================================================================
--- Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/tests/demofs.py 2005-09-08 13:50:32 UTC (rev 38397)
+++ Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/tests/demofs.py 2005-09-08 13:54:03 UTC (rev 38398)
@@ -15,7 +15,7 @@
"""
import posixpath
from zope.security.interfaces import Unauthorized
-from zope.app.server.interfaces import IFileSystem
+from zope.app.twisted.interfaces import IFileSystem
## from zope.server.interfaces.ftp import IFileSystemAccess
from zope.interface import implements
Modified: Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/tests/fstests.py
===================================================================
--- Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/tests/fstests.py 2005-09-08 13:50:32 UTC (rev 38397)
+++ Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/tests/fstests.py 2005-09-08 13:54:03 UTC (rev 38398)
@@ -17,7 +17,7 @@
"""
from StringIO import StringIO
from zope.interface.verify import verifyObject
-from zope.app.server.interfaces import IFileSystem
+from zope.app.twisted.interfaces import IFileSystem
class FileSystemTests(object):
"""Tests of a readable filesystem
Modified: Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/tests/test_accesslog.py
===================================================================
--- Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/tests/test_ftp.py 2005-09-08 13:50:32 UTC (rev 38397)
+++ Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/tests/test_ftp.py 2005-09-08 13:54:03 UTC (rev 38398)
@@ -21,7 +21,7 @@
def test_suite():
pass
#return unittest.TestSuite((
- # DocTestSuite('zope.app.server.ftp'),
+ # DocTestSuite('zope.app.twisted.ftp'),
# ))
if __name__ == '__main__':
Modified: Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/tests/test_mkzopeinstance.py
===================================================================
--- Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/tests/test_mkzopeinstance.py 2005-09-08 13:50:32 UTC (rev 38397)
+++ Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/tests/test_mkzopeinstance.py 2005-09-08 13:54:03 UTC (rev 38398)
@@ -23,7 +23,7 @@
from StringIO import StringIO
-from zope.app.server import mkzopeinstance
+from zope.app.twisted import mkzopeinstance
class TestBase(unittest.TestCase):
Modified: Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/tests/test_publisher.py
===================================================================
--- Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/tests/test_publisher.py 2005-09-08 13:50:32 UTC (rev 38397)
+++ Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/tests/test_publisher.py 2005-09-08 13:54:03 UTC (rev 38398)
@@ -20,7 +20,7 @@
from fstests import FileSystemTests
from StringIO import StringIO
from zope.publisher.publish import mapply
-from zope.app.server.ftp.utils import PublisherFileSystem
+from zope.app.twisted.ftp.utils import PublisherFileSystem
class DemoFileSystem(demofs.DemoFileSystem):
More information about the Zope3-Checkins
mailing list
--- Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/tests/test_accesslog.py 2005-09-08 13:50:32 UTC (rev 38397)
+++ Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/tests/test_accesslog.py 2005-09-08 13:54:03 UTC (rev 38398)
@@ -11,7 +11,7 @@
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Tests for zope.app.server.accesslog.
$Id$
"""
@@ -28,7 +28,7 @@
_schematext = """
<schema>
- <import package='zope.app.server' file='accesslog.xml'/>
+ <import package='zope.app.twisted' file='accesslog.xml'/>
<section type='accesslog' name='*' attribute='accesslog'/>
</schema>
"""
@@ -11,7 +11,7 @@
#
##############################################################################
-"""Tests for zope.app.server.accesslog.
+"""Tests for zope.app.twisted.accesslog.
$Id$
"""
Modified: Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/tests/test_docs.py
===================================================================
--- Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/tests/test_docs.py 2005-09-08 13:50:32 UTC (rev 38397)
+++ Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/tests/test_docs.py 2005-09-08 13:54:03 UTC (rev 38398)
@@ -11,7 +11,7 @@
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Tests for zope.app.server.servertype
$Id$
"""
@@ -54,7 +54,7 @@
doctest.DocFileSuite('../log.txt',
globs={'pprint': doctestunit.pprint},
optionflags=doctest.NORMALIZE_WHITESPACE),
- doctest.DocTestSuite('zope.app.server.ftp.utils')
+ doctest.DocTestSuite('zope.app.twisted.ftp.utils')
))
Modified: Zope3/branches/srichter-twisted-integration2/src/zope/app/twisted/tests/test_ftp.py
===================================================================
@@ -11,7 +11,7 @@
#
##############################################################################
-"""Tests for zope.app.server.servertype
+"""Tests for zope.app.twisted.servertype
$Id$
"""